package de.intevation.flys.importer;

import java.math.BigDecimal;

import java.util.List;

import org.apache.log4j.Logger;

import org.hibernate.Session;
import org.hibernate.Query;

import de.intevation.flys.model.SedimentDensity;
import de.intevation.flys.model.SedimentDensityValue;


public class ImportSedimentDensityValue {

    private static final Logger log =
        Logger.getLogger(ImportSedimentDensityValue.class);


    protected SedimentDensityValue peer;

    protected BigDecimal station;

    protected BigDecimal density;

    protected String description;


    public ImportSedimentDensityValue(
        BigDecimal station,
        BigDecimal density,
        String     description
    ) {
        this.station     = station;
        this.density     = density;
        this.description = description;
    }


    public void storeDependencies(SedimentDensity sedimentDensity) {
        log.info("store dependencies");

        getPeer(sedimentDensity);
    }


    public SedimentDensityValue getPeer(SedimentDensity sedimentDensity) {
        log.info("get peer");

        if (peer == null) {
            Session session = ImporterSession.getInstance().getDatabaseSession();

            Query query = session.createQuery(
                "from SedimentDensityValue where " +
                "   sedimentDensity=:sedimentDensity and " +
                "   station=:station and " +
                "   density=:density and " +
                "   description=:description");

            query.setParameter("sedimentDensity", sedimentDensity);
            query.setParameter("station", station);
            query.setParameter("density", density);
            query.setParameter("description", description);

            List<SedimentDensityValue> values = query.list();
            if (values.isEmpty()) {
                log.debug("Create new SedimentDensityValue DB instance.");

                peer = new SedimentDensityValue(
                    sedimentDensity,
                    station,
                    density,
                    description);

                session.save(peer);
            }
            else {
                peer = values.get(0);
            }
        }

        return peer;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
